@@ -1,11 +1,12 @@
 from __future__ import (absolute_import, division, print_function)
 
 from odm2api.ODMconnection import SessionFactory, dbconnection
-from odm2api.base import serviceBase
+from odm2api.base import modelBase, serviceBase
 
 __all__ = [
     'SessionFactory',
     'dbconnection',
+    'modelBase',
     'serviceBase',
 ]
 
